@@ -28,8 +28,9 @@ usage:
     ia tasks [--task=<task_id>...] [--get-task-log=<task_id>]
              [--parameter=<k:v>...] [--tab-output]
     ia tasks <identifier> [--parameter=<k:v>...] [--tab-output]
-    ia tasks <identifier> --cmd=<command> --comment=<comment>
-                          [--data=<k:v>...] [--tab-output]
+    ia tasks <identifier> --cmd=<command> [--comment=<comment>]
+                          [--task-args=<k:v>...] [--data=<k:v>...]
+                          [--tab-output]
     ia tasks --help
 
 options:
@@ -41,6 +42,7 @@ options:
     -C, --comment=<command>       A reasonable explantion for why a
                                   task is being submitted.
     -T, --tab-output              Output task info in tab-delimited columns.
+    -a, --task-args=<k:v>...      Args to submit to the Tasks API.
     -d, --data=<k:v>...           Additional data to send when submitting
                                   a task.
 
@@ -53,6 +55,8 @@ examples:
 
     ia tasks <id> --cmd make_undark.php --comment '<comment>'  # undark item
     ia tasks <id> --cmd make_dark.php --comment '<comment>'  # dark item
+    ia tasks <id> --cmd fixer.php --task-args noop:1  # submit a noop fixer.php task
+    ia tasks <id> --cmd fixer.php --task-args 'noop:1;asr:1  # submit multiple fixer ops
 """
 from __future__ import absolute_import, print_function
 import sys
@@ -70,6 +74,8 @@ def main(argv, session):
     # Tasks write API.
     if args['--cmd']:
         data = get_args_dict(args['--data'], query_string=True)
+        task_args = get_args_dict(args['--task-args'], query_string=True)
+        data['args'] = task_args
         r = session.submit_task(args['<identifier>'],
                                 args['--cmd'],
                                 comment=args['--comment'],
