@@ -46,7 +46,7 @@ from requests.adapters import HTTPAdapter
 from requests.packages.urllib3 import Retry
 from six.moves.urllib.parse import urlparse, unquote
 
-from internetarchive import __version__
+from internetarchive import __version__, auth
 from internetarchive.config import get_config
 from internetarchive.item import Item, Collection
 from internetarchive.search import Search
@@ -271,7 +271,11 @@ class ArchiveSession(requests.sessions.Session):
         if 'timeout' not in request_kwargs:
             request_kwargs['timeout'] = 12
         try:
-            resp = self.get(url, **request_kwargs)
+            if self.access_key and self.secret_key:
+                s3_auth = auth.S3Auth(self.access_key, self.secret_key)
+            else:
+                s3_auth = None
+            resp = self.get(url, auth=s3_auth, **request_kwargs)
             resp.raise_for_status()
         except Exception as exc:
             error_msg = 'Error retrieving metadata from {0}, {1}'.format(url, exc)
@@ -462,6 +466,26 @@ class ArchiveSession(requests.sessions.Session):
         c = Catalog(self, request_kwargs)
         return c.get_tasks(identifier=identifier, params=params)
 
+    def get_my_catalog(self, params=None, request_kwargs=None):
+        """Get all queued or running tasks.
+
+        :type params: dict
+        :param params: (optional) Query parameters, refer to
+                       `Tasks API
+                       <https://archive.org/services/docs/api/tasks.html>`_
+                       for available parameters.
+
+        :type request_kwargs: dict
+        :param request_kwargs: (optional) Keyword arguments to be used in
+                               :meth:`requests.sessions.Session.get` request.
+
+        :rtype: List[CatalogTask]
+        """
+        params = dict() if not params else params
+        _params = dict(submitter=self.user_email, catalog=1, history=0, summary=0)
+        params.update(_params)
+        return self.get_tasks(params=params, request_kwargs=request_kwargs)
+
     def get_task_log(self, task_id, request_kwargs=None):
         """Get a task log.
 
